# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from hanzoai import Hanzo, AsyncHanzo
from tests.utils import assert_matches_type
from hanzoai.types import (
    LiteLlmTeamTable,
    TeamAddMemberResponse,
    TeamUpdateMemberResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTeam:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Hanzo) -> None:
        team = client.team.create()
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Hanzo) -> None:
        team = client.team.create(
            admins=[{}],
            blocked=True,
            budget_duration="budget_duration",
            guardrails=["string"],
            max_budget=0,
            members=[{}],
            members_with_roles=[
                {
                    "role": "admin",
                    "user_email": "user_email",
                    "user_id": "user_id",
                }
            ],
            metadata={},
            model_aliases={},
            models=[{}],
            organization_id="organization_id",
            rpm_limit=0,
            tags=[{}],
            team_alias="team_alias",
            team_id="team_id",
            tpm_limit=0,
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(LiteLlmTeamTable, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Hanzo) -> None:
        team = client.team.update(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Hanzo) -> None:
        team = client.team.update(
            team_id="team_id",
            blocked=True,
            budget_duration="budget_duration",
            guardrails=["string"],
            max_budget=0,
            metadata={},
            model_aliases={},
            models=[{}],
            organization_id="organization_id",
            rpm_limit=0,
            tags=[{}],
            team_alias="team_alias",
            tpm_limit=0,
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.update(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.update(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Hanzo) -> None:
        team = client.team.list()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Hanzo) -> None:
        team = client.team.list(
            organization_id="organization_id",
            user_id="user_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Hanzo) -> None:
        team = client.team.delete(
            team_ids=["string"],
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_with_all_params(self, client: Hanzo) -> None:
        team = client.team.delete(
            team_ids=["string"],
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.delete(
            team_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.delete(
            team_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_add_member(self, client: Hanzo) -> None:
        team = client.team.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        )
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_add_member_with_all_params(self, client: Hanzo) -> None:
        team = client.team.add_member(
            member=[
                {
                    "role": "admin",
                    "user_email": "user_email",
                    "user_id": "user_id",
                }
            ],
            team_id="team_id",
            max_budget_in_team=0,
        )
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_add_member(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_add_member(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(TeamAddMemberResponse, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_block(self, client: Hanzo) -> None:
        team = client.team.block(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_block(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.block(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_block(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.block(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_disable_logging(self, client: Hanzo) -> None:
        team = client.team.disable_logging(
            "team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_disable_logging(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.disable_logging(
            "team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_disable_logging(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.disable_logging(
            "team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_disable_logging(self, client: Hanzo) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `team_id` but received ''"):
            client.team.with_raw_response.disable_logging(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list_available(self, client: Hanzo) -> None:
        team = client.team.list_available()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_available_with_all_params(self, client: Hanzo) -> None:
        team = client.team.list_available(
            response_model={},
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_available(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.list_available()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_available(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.list_available() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_remove_member(self, client: Hanzo) -> None:
        team = client.team.remove_member(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_remove_member_with_all_params(self, client: Hanzo) -> None:
        team = client.team.remove_member(
            team_id="team_id",
            user_email="user_email",
            user_id="user_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_remove_member(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.remove_member(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_remove_member(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.remove_member(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_info(self, client: Hanzo) -> None:
        team = client.team.retrieve_info()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_info_with_all_params(self, client: Hanzo) -> None:
        team = client.team.retrieve_info(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_info(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.retrieve_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_info(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.retrieve_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_unblock(self, client: Hanzo) -> None:
        team = client.team.unblock(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_unblock(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.unblock(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_unblock(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.unblock(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update_member(self, client: Hanzo) -> None:
        team = client.team.update_member(
            team_id="team_id",
        )
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_member_with_all_params(self, client: Hanzo) -> None:
        team = client.team.update_member(
            team_id="team_id",
            max_budget_in_team=0,
            role="admin",
            user_email="user_email",
            user_id="user_id",
        )
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update_member(self, client: Hanzo) -> None:
        response = client.team.with_raw_response.update_member(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = response.parse()
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update_member(self, client: Hanzo) -> None:
        with client.team.with_streaming_response.update_member(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = response.parse()
            assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTeam:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.create()
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.create(
            admins=[{}],
            blocked=True,
            budget_duration="budget_duration",
            guardrails=["string"],
            max_budget=0,
            members=[{}],
            members_with_roles=[
                {
                    "role": "admin",
                    "user_email": "user_email",
                    "user_id": "user_id",
                }
            ],
            metadata={},
            model_aliases={},
            models=[{}],
            organization_id="organization_id",
            rpm_limit=0,
            tags=[{}],
            team_alias="team_alias",
            team_id="team_id",
            tpm_limit=0,
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(LiteLlmTeamTable, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(LiteLlmTeamTable, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.update(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.update(
            team_id="team_id",
            blocked=True,
            budget_duration="budget_duration",
            guardrails=["string"],
            max_budget=0,
            metadata={},
            model_aliases={},
            models=[{}],
            organization_id="organization_id",
            rpm_limit=0,
            tags=[{}],
            team_alias="team_alias",
            tpm_limit=0,
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.update(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.update(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.list()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.list(
            organization_id="organization_id",
            user_id="user_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.delete(
            team_ids=["string"],
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.delete(
            team_ids=["string"],
            litellm_changed_by="litellm-changed-by",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.delete(
            team_ids=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.delete(
            team_ids=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_add_member(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        )
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_add_member_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.add_member(
            member=[
                {
                    "role": "admin",
                    "user_email": "user_email",
                    "user_id": "user_id",
                }
            ],
            team_id="team_id",
            max_budget_in_team=0,
        )
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_add_member(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(TeamAddMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_add_member(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.add_member(
            member=[{"role": "admin"}],
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(TeamAddMemberResponse, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_block(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.block(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_block(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.block(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_block(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.block(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_disable_logging(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.disable_logging(
            "team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_disable_logging(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.disable_logging(
            "team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_disable_logging(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.disable_logging(
            "team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_disable_logging(self, async_client: AsyncHanzo) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `team_id` but received ''"):
            await async_client.team.with_raw_response.disable_logging(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_available(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.list_available()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_available_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.list_available(
            response_model={},
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_available(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.list_available()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_available(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.list_available() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_remove_member(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.remove_member(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_remove_member_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.remove_member(
            team_id="team_id",
            user_email="user_email",
            user_id="user_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_remove_member(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.remove_member(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_remove_member(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.remove_member(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_info(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.retrieve_info()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_info_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.retrieve_info(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_info(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.retrieve_info()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_info(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.retrieve_info() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_unblock(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.unblock(
            team_id="team_id",
        )
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_unblock(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.unblock(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(object, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_unblock(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.unblock(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(object, team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_member(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.update_member(
            team_id="team_id",
        )
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_member_with_all_params(self, async_client: AsyncHanzo) -> None:
        team = await async_client.team.update_member(
            team_id="team_id",
            max_budget_in_team=0,
            role="admin",
            user_email="user_email",
            user_id="user_id",
        )
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update_member(self, async_client: AsyncHanzo) -> None:
        response = await async_client.team.with_raw_response.update_member(
            team_id="team_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        team = await response.parse()
        assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update_member(self, async_client: AsyncHanzo) -> None:
        async with async_client.team.with_streaming_response.update_member(
            team_id="team_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            team = await response.parse()
            assert_matches_type(TeamUpdateMemberResponse, team, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .organization_table_with_members import OrganizationTableWithMembers

__all__ = ["OrganizationListResponse"]

OrganizationListResponse: TypeAlias = List[OrganizationTableWithMembers]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import delete_create_allowed_ip_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["DeleteResource", "AsyncDeleteResource"]


class DeleteResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DeleteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return DeleteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DeleteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return DeleteResourceWithStreamingResponse(self)

    def create_allowed_ip(
        self,
        *,
        ip: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete Allowed Ip

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/delete/allowed_ip",
            body=maybe_transform({"ip": ip}, delete_create_allowed_ip_params.DeleteCreateAllowedIPParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncDeleteResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDeleteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncDeleteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDeleteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return AsyncDeleteResourceWithStreamingResponse(self)

    async def create_allowed_ip(
        self,
        *,
        ip: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete Allowed Ip

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/delete/allowed_ip",
            body=await async_maybe_transform({"ip": ip}, delete_create_allowed_ip_params.DeleteCreateAllowedIPParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class DeleteResourceWithRawResponse:
    def __init__(self, delete: DeleteResource) -> None:
        self._delete = delete

        self.create_allowed_ip = to_raw_response_wrapper(
            delete.create_allowed_ip,
        )


class AsyncDeleteResourceWithRawResponse:
    def __init__(self, delete: AsyncDeleteResource) -> None:
        self._delete = delete

        self.create_allowed_ip = async_to_raw_response_wrapper(
            delete.create_allowed_ip,
        )


class DeleteResourceWithStreamingResponse:
    def __init__(self, delete: DeleteResource) -> None:
        self._delete = delete

        self.create_allowed_ip = to_streamed_response_wrapper(
            delete.create_allowed_ip,
        )


class AsyncDeleteResourceWithStreamingResponse:
    def __init__(self, delete: AsyncDeleteResource) -> None:
        self._delete = delete

        self.create_allowed_ip = async_to_streamed_response_wrapper(
            delete.create_allowed_ip,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal

import httpx

from ..types import health_check_all_params, health_check_services_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["HealthResource", "AsyncHealthResource"]


class HealthResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HealthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return HealthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HealthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return HealthResourceWithStreamingResponse(self)

    def check_all(
        self,
        *,
        model: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        🚨 USE `/health/liveliness` to health check the proxy 🚨

        See more 👉 https://docs.litellm.ai/docs/proxy/health

        Check the health of all the endpoints in config.yaml

        To run health checks in the background, add this to config.yaml:

        ```
        general_settings:
            # ... other settings
            background_health_checks: True
        ```

        else, the health checks will be run on models when /health is called.

        Args:
          model: Specify the model name (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/health",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"model": model}, health_check_all_params.HealthCheckAllParams),
            ),
            cast_to=object,
        )

    def check_liveliness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker is alive"""
        return self._get(
            "/health/liveliness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def check_liveness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker is alive"""
        return self._get(
            "/health/liveness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def check_readiness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker can receive requests"""
        return self._get(
            "/health/readiness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def check_services(
        self,
        *,
        service: Union[
            Literal[
                "slack_budget_alerts", "langfuse", "slack", "openmeter", "webhook", "email", "braintrust", "datadog"
            ],
            str,
        ],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Use this admin-only endpoint to check if the service is healthy.

        Example:

        ```
        curl -L -X GET 'http://0.0.0.0:4000/health/services?service=datadog'     -H 'Authorization: Bearer sk-1234'
        ```

        Args:
          service: Specify the service being hit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/health/services",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"service": service}, health_check_services_params.HealthCheckServicesParams),
            ),
            cast_to=object,
        )


class AsyncHealthResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHealthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncHealthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHealthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return AsyncHealthResourceWithStreamingResponse(self)

    async def check_all(
        self,
        *,
        model: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        🚨 USE `/health/liveliness` to health check the proxy 🚨

        See more 👉 https://docs.litellm.ai/docs/proxy/health

        Check the health of all the endpoints in config.yaml

        To run health checks in the background, add this to config.yaml:

        ```
        general_settings:
            # ... other settings
            background_health_checks: True
        ```

        else, the health checks will be run on models when /health is called.

        Args:
          model: Specify the model name (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/health",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"model": model}, health_check_all_params.HealthCheckAllParams),
            ),
            cast_to=object,
        )

    async def check_liveliness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker is alive"""
        return await self._get(
            "/health/liveliness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def check_liveness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker is alive"""
        return await self._get(
            "/health/liveness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def check_readiness(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Unprotected endpoint for checking if worker can receive requests"""
        return await self._get(
            "/health/readiness",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def check_services(
        self,
        *,
        service: Union[
            Literal[
                "slack_budget_alerts", "langfuse", "slack", "openmeter", "webhook", "email", "braintrust", "datadog"
            ],
            str,
        ],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Use this admin-only endpoint to check if the service is healthy.

        Example:

        ```
        curl -L -X GET 'http://0.0.0.0:4000/health/services?service=datadog'     -H 'Authorization: Bearer sk-1234'
        ```

        Args:
          service: Specify the service being hit.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/health/services",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"service": service}, health_check_services_params.HealthCheckServicesParams
                ),
            ),
            cast_to=object,
        )


class HealthResourceWithRawResponse:
    def __init__(self, health: HealthResource) -> None:
        self._health = health

        self.check_all = to_raw_response_wrapper(
            health.check_all,
        )
        self.check_liveliness = to_raw_response_wrapper(
            health.check_liveliness,
        )
        self.check_liveness = to_raw_response_wrapper(
            health.check_liveness,
        )
        self.check_readiness = to_raw_response_wrapper(
            health.check_readiness,
        )
        self.check_services = to_raw_response_wrapper(
            health.check_services,
        )


class AsyncHealthResourceWithRawResponse:
    def __init__(self, health: AsyncHealthResource) -> None:
        self._health = health

        self.check_all = async_to_raw_response_wrapper(
            health.check_all,
        )
        self.check_liveliness = async_to_raw_response_wrapper(
            health.check_liveliness,
        )
        self.check_liveness = async_to_raw_response_wrapper(
            health.check_liveness,
        )
        self.check_readiness = async_to_raw_response_wrapper(
            health.check_readiness,
        )
        self.check_services = async_to_raw_response_wrapper(
            health.check_services,
        )


class HealthResourceWithStreamingResponse:
    def __init__(self, health: HealthResource) -> None:
        self._health = health

        self.check_all = to_streamed_response_wrapper(
            health.check_all,
        )
        self.check_liveliness = to_streamed_response_wrapper(
            health.check_liveliness,
        )
        self.check_liveness = to_streamed_response_wrapper(
            health.check_liveness,
        )
        self.check_readiness = to_streamed_response_wrapper(
            health.check_readiness,
        )
        self.check_services = to_streamed_response_wrapper(
            health.check_services,
        )


class AsyncHealthResourceWithStreamingResponse:
    def __init__(self, health: AsyncHealthResource) -> None:
        self._health = health

        self.check_all = async_to_streamed_response_wrapper(
            health.check_all,
        )
        self.check_liveliness = async_to_streamed_response_wrapper(
            health.check_liveliness,
        )
        self.check_liveness = async_to_streamed_response_wrapper(
            health.check_liveness,
        )
        self.check_readiness = async_to_streamed_response_wrapper(
            health.check_readiness,
        )
        self.check_services = async_to_streamed_response_wrapper(
            health.check_services,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .member import Member
from .._models import BaseModel
from .user_roles import UserRoles

__all__ = ["KeyListResponse", "Key", "KeyUserAPIKeyAuth"]


class KeyUserAPIKeyAuth(BaseModel):
    token: Optional[str] = None

    aliases: Optional[object] = None

    allowed_cache_controls: Optional[List[object]] = None

    allowed_model_region: Optional[Literal["eu", "us"]] = None

    api_key: Optional[str] = None

    blocked: Optional[bool] = None

    budget_duration: Optional[str] = None

    budget_reset_at: Optional[datetime] = None

    config: Optional[object] = None

    created_at: Optional[datetime] = None

    created_by: Optional[str] = None

    end_user_id: Optional[str] = None

    end_user_max_budget: Optional[float] = None

    end_user_rpm_limit: Optional[int] = None

    end_user_tpm_limit: Optional[int] = None

    expires: Union[str, datetime, None] = None

    key_alias: Optional[str] = None

    key_name: Optional[str] = None

    last_refreshed_at: Optional[float] = None

    litellm_budget_table: Optional[object] = None

    max_budget: Optional[float] = None

    max_parallel_requests: Optional[int] = None

    metadata: Optional[object] = None

    api_model_max_budget: Optional[object] = FieldInfo(alias="model_max_budget", default=None)

    api_model_spend: Optional[object] = FieldInfo(alias="model_spend", default=None)

    models: Optional[List[object]] = None

    org_id: Optional[str] = None

    parent_otel_span: Optional[object] = None

    permissions: Optional[object] = None

    rpm_limit: Optional[int] = None

    rpm_limit_per_model: Optional[Dict[str, int]] = None

    soft_budget: Optional[float] = None

    soft_budget_cooldown: Optional[bool] = None

    spend: Optional[float] = None

    team_alias: Optional[str] = None

    team_blocked: Optional[bool] = None

    team_id: Optional[str] = None

    team_max_budget: Optional[float] = None

    team_member: Optional[Member] = None

    team_member_spend: Optional[float] = None

    team_metadata: Optional[object] = None

    team_model_aliases: Optional[object] = None

    team_models: Optional[List[object]] = None

    team_rpm_limit: Optional[int] = None

    team_spend: Optional[float] = None

    team_tpm_limit: Optional[int] = None

    tpm_limit: Optional[int] = None

    tpm_limit_per_model: Optional[Dict[str, int]] = None

    updated_at: Optional[datetime] = None

    updated_by: Optional[str] = None

    user_email: Optional[str] = None

    user_id: Optional[str] = None

    user_role: Optional[UserRoles] = None
    """
    Admin Roles: PROXY_ADMIN: admin over the platform PROXY_ADMIN_VIEW_ONLY: can
    login, view all own keys, view all spend ORG_ADMIN: admin over a specific
    organization, can create teams, users only within their organization

    Internal User Roles: INTERNAL_USER: can login, view/create/delete their own
    keys, view their spend INTERNAL_USER_VIEW_ONLY: can login, view their own keys,
    view their own spend

    Team Roles: TEAM: used for JWT auth

    Customer Roles: CUSTOMER: External users -> these are customers
    """

    user_rpm_limit: Optional[int] = None

    user_tpm_limit: Optional[int] = None


Key: TypeAlias = Union[str, KeyUserAPIKeyAuth]


class KeyListResponse(BaseModel):
    current_page: Optional[int] = None

    keys: Optional[List[Key]] = None

    total_count: Optional[int] = None

    total_pages: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Union, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    NOT_GIVEN,
    Body,
    Omit,
    Query,
    Headers,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
)
from ._utils import (
    is_given,
    get_async_library,
)
from ._version import __version__
from ._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .resources import (
    add,
    test,
    user,
    azure,
    spend,
    utils,
    active,
    budget,
    cohere,
    delete,
    gemini,
    health,
    models,
    rerank,
    routes,
    bedrock,
    customer,
    langfuse,
    provider,
    settings,
    anthropic,
    vertex_ai,
    assemblyai,
    assistants,
    embeddings,
    guardrails,
    completions,
    credentials,
    model_group,
    moderations,
    eu_assemblyai,
)
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import HanzoError, APIStatusError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
    make_request_options,
)
from .resources.key import key
from .resources.chat import chat
from .resources.team import team
from .resources.audio import audio
from .resources.cache import cache
from .resources.files import files
from .resources.model import model
from .resources.config import config
from .resources.images import images
from .resources.openai import openai
from .resources.batches import batches
from .resources.engines import engines
from .resources.global_ import global_
from .resources.threads import threads
from .resources.responses import responses
from .resources.fine_tuning import fine_tuning
from .resources.organization import organization

__all__ = ["Timeout", "Transport", "ProxiesTypes", "RequestOptions", "Hanzo", "AsyncHanzo", "Client", "AsyncClient"]


class Hanzo(SyncAPIClient):
    models: models.ModelsResource
    openai: openai.OpenAIResource
    engines: engines.EnginesResource
    chat: chat.ChatResource
    completions: completions.CompletionsResource
    embeddings: embeddings.EmbeddingsResource
    images: images.ImagesResource
    audio: audio.AudioResource
    assistants: assistants.AssistantsResource
    threads: threads.ThreadsResource
    moderations: moderations.ModerationsResource
    utils: utils.UtilsResource
    model: model.ModelResource
    model_group: model_group.ModelGroupResource
    routes: routes.RoutesResource
    responses: responses.ResponsesResource
    batches: batches.BatchesResource
    rerank: rerank.RerankResource
    fine_tuning: fine_tuning.FineTuningResource
    credentials: credentials.CredentialsResource
    vertex_ai: vertex_ai.VertexAIResource
    gemini: gemini.GeminiResource
    cohere: cohere.CohereResource
    anthropic: anthropic.AnthropicResource
    bedrock: bedrock.BedrockResource
    eu_assemblyai: eu_assemblyai.EuAssemblyaiResource
    assemblyai: assemblyai.AssemblyaiResource
    azure: azure.AzureResource
    langfuse: langfuse.LangfuseResource
    config: config.ConfigResource
    test: test.TestResource
    health: health.HealthResource
    active: active.ActiveResource
    settings: settings.SettingsResource
    key: key.KeyResource
    user: user.UserResource
    team: team.TeamResource
    organization: organization.OrganizationResource
    customer: customer.CustomerResource
    spend: spend.SpendResource
    global_: global_.GlobalResource
    provider: provider.ProviderResource
    cache: cache.CacheResource
    guardrails: guardrails.GuardrailsResource
    add: add.AddResource
    delete: delete.DeleteResource
    files: files.FilesResource
    budget: budget.BudgetResource
    with_raw_response: HanzoWithRawResponse
    with_streaming_response: HanzoWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous Hanzo client instance.

        This automatically infers the `api_key` argument from the `HANZO_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("HANZO_API_KEY")
        if api_key is None:
            raise HanzoError(
                "The api_key client option must be set either by passing api_key to the client or by setting the HANZO_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("HANZO_BASE_URL")
        if base_url is None:
            base_url = f"https://api.hanzo.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.models = models.ModelsResource(self)
        self.openai = openai.OpenAIResource(self)
        self.engines = engines.EnginesResource(self)
        self.chat = chat.ChatResource(self)
        self.completions = completions.CompletionsResource(self)
        self.embeddings = embeddings.EmbeddingsResource(self)
        self.images = images.ImagesResource(self)
        self.audio = audio.AudioResource(self)
        self.assistants = assistants.AssistantsResource(self)
        self.threads = threads.ThreadsResource(self)
        self.moderations = moderations.ModerationsResource(self)
        self.utils = utils.UtilsResource(self)
        self.model = model.ModelResource(self)
        self.model_group = model_group.ModelGroupResource(self)
        self.routes = routes.RoutesResource(self)
        self.responses = responses.ResponsesResource(self)
        self.batches = batches.BatchesResource(self)
        self.rerank = rerank.RerankResource(self)
        self.fine_tuning = fine_tuning.FineTuningResource(self)
        self.credentials = credentials.CredentialsResource(self)
        self.vertex_ai = vertex_ai.VertexAIResource(self)
        self.gemini = gemini.GeminiResource(self)
        self.cohere = cohere.CohereResource(self)
        self.anthropic = anthropic.AnthropicResource(self)
        self.bedrock = bedrock.BedrockResource(self)
        self.eu_assemblyai = eu_assemblyai.EuAssemblyaiResource(self)
        self.assemblyai = assemblyai.AssemblyaiResource(self)
        self.azure = azure.AzureResource(self)
        self.langfuse = langfuse.LangfuseResource(self)
        self.config = config.ConfigResource(self)
        self.test = test.TestResource(self)
        self.health = health.HealthResource(self)
        self.active = active.ActiveResource(self)
        self.settings = settings.SettingsResource(self)
        self.key = key.KeyResource(self)
        self.user = user.UserResource(self)
        self.team = team.TeamResource(self)
        self.organization = organization.OrganizationResource(self)
        self.customer = customer.CustomerResource(self)
        self.spend = spend.SpendResource(self)
        self.global_ = global_.GlobalResource(self)
        self.provider = provider.ProviderResource(self)
        self.cache = cache.CacheResource(self)
        self.guardrails = guardrails.GuardrailsResource(self)
        self.add = add.AddResource(self)
        self.delete = delete.DeleteResource(self)
        self.files = files.FilesResource(self)
        self.budget = budget.BudgetResource(self)
        self.with_raw_response = HanzoWithRawResponse(self)
        self.with_streaming_response = HanzoWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Ocp-Apim-Subscription-Key": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def get_home(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Home"""
        return self.get(
            "/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncHanzo(AsyncAPIClient):
    models: models.AsyncModelsResource
    openai: openai.AsyncOpenAIResource
    engines: engines.AsyncEnginesResource
    chat: chat.AsyncChatResource
    completions: completions.AsyncCompletionsResource
    embeddings: embeddings.AsyncEmbeddingsResource
    images: images.AsyncImagesResource
    audio: audio.AsyncAudioResource
    assistants: assistants.AsyncAssistantsResource
    threads: threads.AsyncThreadsResource
    moderations: moderations.AsyncModerationsResource
    utils: utils.AsyncUtilsResource
    model: model.AsyncModelResource
    model_group: model_group.AsyncModelGroupResource
    routes: routes.AsyncRoutesResource
    responses: responses.AsyncResponsesResource
    batches: batches.AsyncBatchesResource
    rerank: rerank.AsyncRerankResource
    fine_tuning: fine_tuning.AsyncFineTuningResource
    credentials: credentials.AsyncCredentialsResource
    vertex_ai: vertex_ai.AsyncVertexAIResource
    gemini: gemini.AsyncGeminiResource
    cohere: cohere.AsyncCohereResource
    anthropic: anthropic.AsyncAnthropicResource
    bedrock: bedrock.AsyncBedrockResource
    eu_assemblyai: eu_assemblyai.AsyncEuAssemblyaiResource
    assemblyai: assemblyai.AsyncAssemblyaiResource
    azure: azure.AsyncAzureResource
    langfuse: langfuse.AsyncLangfuseResource
    config: config.AsyncConfigResource
    test: test.AsyncTestResource
    health: health.AsyncHealthResource
    active: active.AsyncActiveResource
    settings: settings.AsyncSettingsResource
    key: key.AsyncKeyResource
    user: user.AsyncUserResource
    team: team.AsyncTeamResource
    organization: organization.AsyncOrganizationResource
    customer: customer.AsyncCustomerResource
    spend: spend.AsyncSpendResource
    global_: global_.AsyncGlobalResource
    provider: provider.AsyncProviderResource
    cache: cache.AsyncCacheResource
    guardrails: guardrails.AsyncGuardrailsResource
    add: add.AsyncAddResource
    delete: delete.AsyncDeleteResource
    files: files.AsyncFilesResource
    budget: budget.AsyncBudgetResource
    with_raw_response: AsyncHanzoWithRawResponse
    with_streaming_response: AsyncHanzoWithStreamedResponse

    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: Union[float, Timeout, None, NotGiven] = NOT_GIVEN,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncHanzo client instance.

        This automatically infers the `api_key` argument from the `HANZO_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("HANZO_API_KEY")
        if api_key is None:
            raise HanzoError(
                "The api_key client option must be set either by passing api_key to the client or by setting the HANZO_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("HANZO_BASE_URL")
        if base_url is None:
            base_url = f"https://api.hanzo.ai"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

        self.models = models.AsyncModelsResource(self)
        self.openai = openai.AsyncOpenAIResource(self)
        self.engines = engines.AsyncEnginesResource(self)
        self.chat = chat.AsyncChatResource(self)
        self.completions = completions.AsyncCompletionsResource(self)
        self.embeddings = embeddings.AsyncEmbeddingsResource(self)
        self.images = images.AsyncImagesResource(self)
        self.audio = audio.AsyncAudioResource(self)
        self.assistants = assistants.AsyncAssistantsResource(self)
        self.threads = threads.AsyncThreadsResource(self)
        self.moderations = moderations.AsyncModerationsResource(self)
        self.utils = utils.AsyncUtilsResource(self)
        self.model = model.AsyncModelResource(self)
        self.model_group = model_group.AsyncModelGroupResource(self)
        self.routes = routes.AsyncRoutesResource(self)
        self.responses = responses.AsyncResponsesResource(self)
        self.batches = batches.AsyncBatchesResource(self)
        self.rerank = rerank.AsyncRerankResource(self)
        self.fine_tuning = fine_tuning.AsyncFineTuningResource(self)
        self.credentials = credentials.AsyncCredentialsResource(self)
        self.vertex_ai = vertex_ai.AsyncVertexAIResource(self)
        self.gemini = gemini.AsyncGeminiResource(self)
        self.cohere = cohere.AsyncCohereResource(self)
        self.anthropic = anthropic.AsyncAnthropicResource(self)
        self.bedrock = bedrock.AsyncBedrockResource(self)
        self.eu_assemblyai = eu_assemblyai.AsyncEuAssemblyaiResource(self)
        self.assemblyai = assemblyai.AsyncAssemblyaiResource(self)
        self.azure = azure.AsyncAzureResource(self)
        self.langfuse = langfuse.AsyncLangfuseResource(self)
        self.config = config.AsyncConfigResource(self)
        self.test = test.AsyncTestResource(self)
        self.health = health.AsyncHealthResource(self)
        self.active = active.AsyncActiveResource(self)
        self.settings = settings.AsyncSettingsResource(self)
        self.key = key.AsyncKeyResource(self)
        self.user = user.AsyncUserResource(self)
        self.team = team.AsyncTeamResource(self)
        self.organization = organization.AsyncOrganizationResource(self)
        self.customer = customer.AsyncCustomerResource(self)
        self.spend = spend.AsyncSpendResource(self)
        self.global_ = global_.AsyncGlobalResource(self)
        self.provider = provider.AsyncProviderResource(self)
        self.cache = cache.AsyncCacheResource(self)
        self.guardrails = guardrails.AsyncGuardrailsResource(self)
        self.add = add.AsyncAddResource(self)
        self.delete = delete.AsyncDeleteResource(self)
        self.files = files.AsyncFilesResource(self)
        self.budget = budget.AsyncBudgetResource(self)
        self.with_raw_response = AsyncHanzoWithRawResponse(self)
        self.with_streaming_response = AsyncHanzoWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Ocp-Apim-Subscription-Key": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = NOT_GIVEN,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = NOT_GIVEN,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    async def get_home(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Home"""
        return await self.get(
            "/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class HanzoWithRawResponse:
    def __init__(self, client: Hanzo) -> None:
        self.models = models.ModelsResourceWithRawResponse(client.models)
        self.openai = openai.OpenAIResourceWithRawResponse(client.openai)
        self.engines = engines.EnginesResourceWithRawResponse(client.engines)
        self.chat = chat.ChatResourceWithRawResponse(client.chat)
        self.completions = completions.CompletionsResourceWithRawResponse(client.completions)
        self.embeddings = embeddings.EmbeddingsResourceWithRawResponse(client.embeddings)
        self.images = images.ImagesResourceWithRawResponse(client.images)
        self.audio = audio.AudioResourceWithRawResponse(client.audio)
        self.assistants = assistants.AssistantsResourceWithRawResponse(client.assistants)
        self.threads = threads.ThreadsResourceWithRawResponse(client.threads)
        self.moderations = moderations.ModerationsResourceWithRawResponse(client.moderations)
        self.utils = utils.UtilsResourceWithRawResponse(client.utils)
        self.model = model.ModelResourceWithRawResponse(client.model)
        self.model_group = model_group.ModelGroupResourceWithRawResponse(client.model_group)
        self.routes = routes.RoutesResourceWithRawResponse(client.routes)
        self.responses = responses.ResponsesResourceWithRawResponse(client.responses)
        self.batches = batches.BatchesResourceWithRawResponse(client.batches)
        self.rerank = rerank.RerankResourceWithRawResponse(client.rerank)
        self.fine_tuning = fine_tuning.FineTuningResourceWithRawResponse(client.fine_tuning)
        self.credentials = credentials.CredentialsResourceWithRawResponse(client.credentials)
        self.vertex_ai = vertex_ai.VertexAIResourceWithRawResponse(client.vertex_ai)
        self.gemini = gemini.GeminiResourceWithRawResponse(client.gemini)
        self.cohere = cohere.CohereResourceWithRawResponse(client.cohere)
        self.anthropic = anthropic.AnthropicResourceWithRawResponse(client.anthropic)
        self.bedrock = bedrock.BedrockResourceWithRawResponse(client.bedrock)
        self.eu_assemblyai = eu_assemblyai.EuAssemblyaiResourceWithRawResponse(client.eu_assemblyai)
        self.assemblyai = assemblyai.AssemblyaiResourceWithRawResponse(client.assemblyai)
        self.azure = azure.AzureResourceWithRawResponse(client.azure)
        self.langfuse = langfuse.LangfuseResourceWithRawResponse(client.langfuse)
        self.config = config.ConfigResourceWithRawResponse(client.config)
        self.test = test.TestResourceWithRawResponse(client.test)
        self.health = health.HealthResourceWithRawResponse(client.health)
        self.active = active.ActiveResourceWithRawResponse(client.active)
        self.settings = settings.SettingsResourceWithRawResponse(client.settings)
        self.key = key.KeyResourceWithRawResponse(client.key)
        self.user = user.UserResourceWithRawResponse(client.user)
        self.team = team.TeamResourceWithRawResponse(client.team)
        self.organization = organization.OrganizationResourceWithRawResponse(client.organization)
        self.customer = customer.CustomerResourceWithRawResponse(client.customer)
        self.spend = spend.SpendResourceWithRawResponse(client.spend)
        self.global_ = global_.GlobalResourceWithRawResponse(client.global_)
        self.provider = provider.ProviderResourceWithRawResponse(client.provider)
        self.cache = cache.CacheResourceWithRawResponse(client.cache)
        self.guardrails = guardrails.GuardrailsResourceWithRawResponse(client.guardrails)
        self.add = add.AddResourceWithRawResponse(client.add)
        self.delete = delete.DeleteResourceWithRawResponse(client.delete)
        self.files = files.FilesResourceWithRawResponse(client.files)
        self.budget = budget.BudgetResourceWithRawResponse(client.budget)

        self.get_home = to_raw_response_wrapper(
            client.get_home,
        )


class AsyncHanzoWithRawResponse:
    def __init__(self, client: AsyncHanzo) -> None:
        self.models = models.AsyncModelsResourceWithRawResponse(client.models)
        self.openai = openai.AsyncOpenAIResourceWithRawResponse(client.openai)
        self.engines = engines.AsyncEnginesResourceWithRawResponse(client.engines)
        self.chat = chat.AsyncChatResourceWithRawResponse(client.chat)
        self.completions = completions.AsyncCompletionsResourceWithRawResponse(client.completions)
        self.embeddings = embeddings.AsyncEmbeddingsResourceWithRawResponse(client.embeddings)
        self.images = images.AsyncImagesResourceWithRawResponse(client.images)
        self.audio = audio.AsyncAudioResourceWithRawResponse(client.audio)
        self.assistants = assistants.AsyncAssistantsResourceWithRawResponse(client.assistants)
        self.threads = threads.AsyncThreadsResourceWithRawResponse(client.threads)
        self.moderations = moderations.AsyncModerationsResourceWithRawResponse(client.moderations)
        self.utils = utils.AsyncUtilsResourceWithRawResponse(client.utils)
        self.model = model.AsyncModelResourceWithRawResponse(client.model)
        self.model_group = model_group.AsyncModelGroupResourceWithRawResponse(client.model_group)
        self.routes = routes.AsyncRoutesResourceWithRawResponse(client.routes)
        self.responses = responses.AsyncResponsesResourceWithRawResponse(client.responses)
        self.batches = batches.AsyncBatchesResourceWithRawResponse(client.batches)
        self.rerank = rerank.AsyncRerankResourceWithRawResponse(client.rerank)
        self.fine_tuning = fine_tuning.AsyncFineTuningResourceWithRawResponse(client.fine_tuning)
        self.credentials = credentials.AsyncCredentialsResourceWithRawResponse(client.credentials)
        self.vertex_ai = vertex_ai.AsyncVertexAIResourceWithRawResponse(client.vertex_ai)
        self.gemini = gemini.AsyncGeminiResourceWithRawResponse(client.gemini)
        self.cohere = cohere.AsyncCohereResourceWithRawResponse(client.cohere)
        self.anthropic = anthropic.AsyncAnthropicResourceWithRawResponse(client.anthropic)
        self.bedrock = bedrock.AsyncBedrockResourceWithRawResponse(client.bedrock)
        self.eu_assemblyai = eu_assemblyai.AsyncEuAssemblyaiResourceWithRawResponse(client.eu_assemblyai)
        self.assemblyai = assemblyai.AsyncAssemblyaiResourceWithRawResponse(client.assemblyai)
        self.azure = azure.AsyncAzureResourceWithRawResponse(client.azure)
        self.langfuse = langfuse.AsyncLangfuseResourceWithRawResponse(client.langfuse)
        self.config = config.AsyncConfigResourceWithRawResponse(client.config)
        self.test = test.AsyncTestResourceWithRawResponse(client.test)
        self.health = health.AsyncHealthResourceWithRawResponse(client.health)
        self.active = active.AsyncActiveResourceWithRawResponse(client.active)
        self.settings = settings.AsyncSettingsResourceWithRawResponse(client.settings)
        self.key = key.AsyncKeyResourceWithRawResponse(client.key)
        self.user = user.AsyncUserResourceWithRawResponse(client.user)
        self.team = team.AsyncTeamResourceWithRawResponse(client.team)
        self.organization = organization.AsyncOrganizationResourceWithRawResponse(client.organization)
        self.customer = customer.AsyncCustomerResourceWithRawResponse(client.customer)
        self.spend = spend.AsyncSpendResourceWithRawResponse(client.spend)
        self.global_ = global_.AsyncGlobalResourceWithRawResponse(client.global_)
        self.provider = provider.AsyncProviderResourceWithRawResponse(client.provider)
        self.cache = cache.AsyncCacheResourceWithRawResponse(client.cache)
        self.guardrails = guardrails.AsyncGuardrailsResourceWithRawResponse(client.guardrails)
        self.add = add.AsyncAddResourceWithRawResponse(client.add)
        self.delete = delete.AsyncDeleteResourceWithRawResponse(client.delete)
        self.files = files.AsyncFilesResourceWithRawResponse(client.files)
        self.budget = budget.AsyncBudgetResourceWithRawResponse(client.budget)

        self.get_home = async_to_raw_response_wrapper(
            client.get_home,
        )


class HanzoWithStreamedResponse:
    def __init__(self, client: Hanzo) -> None:
        self.models = models.ModelsResourceWithStreamingResponse(client.models)
        self.openai = openai.OpenAIResourceWithStreamingResponse(client.openai)
        self.engines = engines.EnginesResourceWithStreamingResponse(client.engines)
        self.chat = chat.ChatResourceWithStreamingResponse(client.chat)
        self.completions = completions.CompletionsResourceWithStreamingResponse(client.completions)
        self.embeddings = embeddings.EmbeddingsResourceWithStreamingResponse(client.embeddings)
        self.images = images.ImagesResourceWithStreamingResponse(client.images)
        self.audio = audio.AudioResourceWithStreamingResponse(client.audio)
        self.assistants = assistants.AssistantsResourceWithStreamingResponse(client.assistants)
        self.threads = threads.ThreadsResourceWithStreamingResponse(client.threads)
        self.moderations = moderations.ModerationsResourceWithStreamingResponse(client.moderations)
        self.utils = utils.UtilsResourceWithStreamingResponse(client.utils)
        self.model = model.ModelResourceWithStreamingResponse(client.model)
        self.model_group = model_group.ModelGroupResourceWithStreamingResponse(client.model_group)
        self.routes = routes.RoutesResourceWithStreamingResponse(client.routes)
        self.responses = responses.ResponsesResourceWithStreamingResponse(client.responses)
        self.batches = batches.BatchesResourceWithStreamingResponse(client.batches)
        self.rerank = rerank.RerankResourceWithStreamingResponse(client.rerank)
        self.fine_tuning = fine_tuning.FineTuningResourceWithStreamingResponse(client.fine_tuning)
        self.credentials = credentials.CredentialsResourceWithStreamingResponse(client.credentials)
        self.vertex_ai = vertex_ai.VertexAIResourceWithStreamingResponse(client.vertex_ai)
        self.gemini = gemini.GeminiResourceWithStreamingResponse(client.gemini)
        self.cohere = cohere.CohereResourceWithStreamingResponse(client.cohere)
        self.anthropic = anthropic.AnthropicResourceWithStreamingResponse(client.anthropic)
        self.bedrock = bedrock.BedrockResourceWithStreamingResponse(client.bedrock)
        self.eu_assemblyai = eu_assemblyai.EuAssemblyaiResourceWithStreamingResponse(client.eu_assemblyai)
        self.assemblyai = assemblyai.AssemblyaiResourceWithStreamingResponse(client.assemblyai)
        self.azure = azure.AzureResourceWithStreamingResponse(client.azure)
        self.langfuse = langfuse.LangfuseResourceWithStreamingResponse(client.langfuse)
        self.config = config.ConfigResourceWithStreamingResponse(client.config)
        self.test = test.TestResourceWithStreamingResponse(client.test)
        self.health = health.HealthResourceWithStreamingResponse(client.health)
        self.active = active.ActiveResourceWithStreamingResponse(client.active)
        self.settings = settings.SettingsResourceWithStreamingResponse(client.settings)
        self.key = key.KeyResourceWithStreamingResponse(client.key)
        self.user = user.UserResourceWithStreamingResponse(client.user)
        self.team = team.TeamResourceWithStreamingResponse(client.team)
        self.organization = organization.OrganizationResourceWithStreamingResponse(client.organization)
        self.customer = customer.CustomerResourceWithStreamingResponse(client.customer)
        self.spend = spend.SpendResourceWithStreamingResponse(client.spend)
        self.global_ = global_.GlobalResourceWithStreamingResponse(client.global_)
        self.provider = provider.ProviderResourceWithStreamingResponse(client.provider)
        self.cache = cache.CacheResourceWithStreamingResponse(client.cache)
        self.guardrails = guardrails.GuardrailsResourceWithStreamingResponse(client.guardrails)
        self.add = add.AddResourceWithStreamingResponse(client.add)
        self.delete = delete.DeleteResourceWithStreamingResponse(client.delete)
        self.files = files.FilesResourceWithStreamingResponse(client.files)
        self.budget = budget.BudgetResourceWithStreamingResponse(client.budget)

        self.get_home = to_streamed_response_wrapper(
            client.get_home,
        )


class AsyncHanzoWithStreamedResponse:
    def __init__(self, client: AsyncHanzo) -> None:
        self.models = models.AsyncModelsResourceWithStreamingResponse(client.models)
        self.openai = openai.AsyncOpenAIResourceWithStreamingResponse(client.openai)
        self.engines = engines.AsyncEnginesResourceWithStreamingResponse(client.engines)
        self.chat = chat.AsyncChatResourceWithStreamingResponse(client.chat)
        self.completions = completions.AsyncCompletionsResourceWithStreamingResponse(client.completions)
        self.embeddings = embeddings.AsyncEmbeddingsResourceWithStreamingResponse(client.embeddings)
        self.images = images.AsyncImagesResourceWithStreamingResponse(client.images)
        self.audio = audio.AsyncAudioResourceWithStreamingResponse(client.audio)
        self.assistants = assistants.AsyncAssistantsResourceWithStreamingResponse(client.assistants)
        self.threads = threads.AsyncThreadsResourceWithStreamingResponse(client.threads)
        self.moderations = moderations.AsyncModerationsResourceWithStreamingResponse(client.moderations)
        self.utils = utils.AsyncUtilsResourceWithStreamingResponse(client.utils)
        self.model = model.AsyncModelResourceWithStreamingResponse(client.model)
        self.model_group = model_group.AsyncModelGroupResourceWithStreamingResponse(client.model_group)
        self.routes = routes.AsyncRoutesResourceWithStreamingResponse(client.routes)
        self.responses = responses.AsyncResponsesResourceWithStreamingResponse(client.responses)
        self.batches = batches.AsyncBatchesResourceWithStreamingResponse(client.batches)
        self.rerank = rerank.AsyncRerankResourceWithStreamingResponse(client.rerank)
        self.fine_tuning = fine_tuning.AsyncFineTuningResourceWithStreamingResponse(client.fine_tuning)
        self.credentials = credentials.AsyncCredentialsResourceWithStreamingResponse(client.credentials)
        self.vertex_ai = vertex_ai.AsyncVertexAIResourceWithStreamingResponse(client.vertex_ai)
        self.gemini = gemini.AsyncGeminiResourceWithStreamingResponse(client.gemini)
        self.cohere = cohere.AsyncCohereResourceWithStreamingResponse(client.cohere)
        self.anthropic = anthropic.AsyncAnthropicResourceWithStreamingResponse(client.anthropic)
        self.bedrock = bedrock.AsyncBedrockResourceWithStreamingResponse(client.bedrock)
        self.eu_assemblyai = eu_assemblyai.AsyncEuAssemblyaiResourceWithStreamingResponse(client.eu_assemblyai)
        self.assemblyai = assemblyai.AsyncAssemblyaiResourceWithStreamingResponse(client.assemblyai)
        self.azure = azure.AsyncAzureResourceWithStreamingResponse(client.azure)
        self.langfuse = langfuse.AsyncLangfuseResourceWithStreamingResponse(client.langfuse)
        self.config = config.AsyncConfigResourceWithStreamingResponse(client.config)
        self.test = test.AsyncTestResourceWithStreamingResponse(client.test)
        self.health = health.AsyncHealthResourceWithStreamingResponse(client.health)
        self.active = active.AsyncActiveResourceWithStreamingResponse(client.active)
        self.settings = settings.AsyncSettingsResourceWithStreamingResponse(client.settings)
        self.key = key.AsyncKeyResourceWithStreamingResponse(client.key)
        self.user = user.AsyncUserResourceWithStreamingResponse(client.user)
        self.team = team.AsyncTeamResourceWithStreamingResponse(client.team)
        self.organization = organization.AsyncOrganizationResourceWithStreamingResponse(client.organization)
        self.customer = customer.AsyncCustomerResourceWithStreamingResponse(client.customer)
        self.spend = spend.AsyncSpendResourceWithStreamingResponse(client.spend)
        self.global_ = global_.AsyncGlobalResourceWithStreamingResponse(client.global_)
        self.provider = provider.AsyncProviderResourceWithStreamingResponse(client.provider)
        self.cache = cache.AsyncCacheResourceWithStreamingResponse(client.cache)
        self.guardrails = guardrails.AsyncGuardrailsResourceWithStreamingResponse(client.guardrails)
        self.add = add.AsyncAddResourceWithStreamingResponse(client.add)
        self.delete = delete.AsyncDeleteResourceWithStreamingResponse(client.delete)
        self.files = files.AsyncFilesResourceWithStreamingResponse(client.files)
        self.budget = budget.AsyncBudgetResourceWithStreamingResponse(client.budget)

        self.get_home = async_to_streamed_response_wrapper(
            client.get_home,
        )


Client = Hanzo

AsyncClient = AsyncHanzo



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.guardrail_list_response import GuardrailListResponse

__all__ = ["GuardrailsResource", "AsyncGuardrailsResource"]


class GuardrailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GuardrailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return GuardrailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GuardrailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return GuardrailsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GuardrailListResponse:
        """
        List the guardrails that are available on the proxy server

        👉 [Guardrail docs](https://docs.litellm.ai/docs/proxy/guardrails/quick_start)

        Example Request:

        ```bash
        curl -X GET "http://localhost:4000/guardrails/list" -H "Authorization: Bearer <your_api_key>"
        ```

        Example Response:

        ```json
        {
          "guardrails": [
            {
              "guardrail_name": "bedrock-pre-guard",
              "guardrail_info": {
                "params": [
                  {
                    "name": "toxicity_score",
                    "type": "float",
                    "description": "Score between 0-1 indicating content toxicity level"
                  },
                  {
                    "name": "pii_detection",
                    "type": "boolean"
                  }
                ]
              }
            }
          ]
        }
        ```
        """
        return self._get(
            "/guardrails/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GuardrailListResponse,
        )


class AsyncGuardrailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGuardrailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncGuardrailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGuardrailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return AsyncGuardrailsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GuardrailListResponse:
        """
        List the guardrails that are available on the proxy server

        👉 [Guardrail docs](https://docs.litellm.ai/docs/proxy/guardrails/quick_start)

        Example Request:

        ```bash
        curl -X GET "http://localhost:4000/guardrails/list" -H "Authorization: Bearer <your_api_key>"
        ```

        Example Response:

        ```json
        {
          "guardrails": [
            {
              "guardrail_name": "bedrock-pre-guard",
              "guardrail_info": {
                "params": [
                  {
                    "name": "toxicity_score",
                    "type": "float",
                    "description": "Score between 0-1 indicating content toxicity level"
                  },
                  {
                    "name": "pii_detection",
                    "type": "boolean"
                  }
                ]
              }
            }
          ]
        }
        ```
        """
        return await self._get(
            "/guardrails/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GuardrailListResponse,
        )


class GuardrailsResourceWithRawResponse:
    def __init__(self, guardrails: GuardrailsResource) -> None:
        self._guardrails = guardrails

        self.list = to_raw_response_wrapper(
            guardrails.list,
        )


class AsyncGuardrailsResourceWithRawResponse:
    def __init__(self, guardrails: AsyncGuardrailsResource) -> None:
        self._guardrails = guardrails

        self.list = async_to_raw_response_wrapper(
            guardrails.list,
        )


class GuardrailsResourceWithStreamingResponse:
    def __init__(self, guardrails: GuardrailsResource) -> None:
        self._guardrails = guardrails

        self.list = to_streamed_response_wrapper(
            guardrails.list,
        )


class AsyncGuardrailsResourceWithStreamingResponse:
    def __init__(self, guardrails: AsyncGuardrailsResource) -> None:
        self._guardrails = guardrails

        self.list = async_to_streamed_response_wrapper(
            guardrails.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from .._models import BaseModel

__all__ = ["ProviderListBudgetsResponse", "Providers"]


class Providers(BaseModel):
    budget_limit: Optional[float] = None

    time_period: Optional[str] = None

    budget_reset_at: Optional[str] = None

    spend: Optional[float] = None


class ProviderListBudgetsResponse(BaseModel):
    providers: Optional[Dict[str, Providers]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["UserListParams"]


class UserListParams(TypedDict, total=False):
    page: int
    """Page number"""

    page_size: int
    """Number of items per page"""

    role: Optional[str]
    """Filter users by role"""

    user_ids: Optional[str]
    """Get list of users by user_ids"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .redis import (
    RedisResource,
    AsyncRedisResource,
    RedisResourceWithRawResponse,
    AsyncRedisResourceWithRawResponse,
    RedisResourceWithStreamingResponse,
    AsyncRedisResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.cache_ping_response import CachePingResponse

__all__ = ["CacheResource", "AsyncCacheResource"]


class CacheResource(SyncAPIResource):
    @cached_property
    def redis(self) -> RedisResource:
        return RedisResource(self._client)

    @cached_property
    def with_raw_response(self) -> CacheResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return CacheResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CacheResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return CacheResourceWithStreamingResponse(self)

    def delete(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Endpoint for deleting a key from the cache.

        All responses from litellm proxy
        have `x-litellm-cache-key` in the headers

        Parameters:

        - **keys**: _Optional[List[str]]_ - A list of keys to delete from the cache.
          Example {"keys": ["key1", "key2"]}

        ```shell
        curl -X POST "http://0.0.0.0:4000/cache/delete"     -H "Authorization: Bearer sk-1234"     -d '{"keys": ["key1", "key2"]}'
        ```
        """
        return self._post(
            "/cache/delete",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def flush_all(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """A function to flush all items from the cache.

        (All items will be deleted from
        the cache with this) Raises HTTPException if the cache is not initialized or if
        the cache type does not support flushing. Returns a dictionary with the status
        of the operation.

        Usage:

        ```
        curl -X POST http://0.0.0.0:4000/cache/flushall -H "Authorization: Bearer sk-1234"
        ```
        """
        return self._post(
            "/cache/flushall",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def ping(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CachePingResponse:
        """Endpoint for checking if cache can be pinged"""
        return self._get(
            "/cache/ping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CachePingResponse,
        )


class AsyncCacheResource(AsyncAPIResource):
    @cached_property
    def redis(self) -> AsyncRedisResource:
        return AsyncRedisResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCacheResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncCacheResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCacheResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return AsyncCacheResourceWithStreamingResponse(self)

    async def delete(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Endpoint for deleting a key from the cache.

        All responses from litellm proxy
        have `x-litellm-cache-key` in the headers

        Parameters:

        - **keys**: _Optional[List[str]]_ - A list of keys to delete from the cache.
          Example {"keys": ["key1", "key2"]}

        ```shell
        curl -X POST "http://0.0.0.0:4000/cache/delete"     -H "Authorization: Bearer sk-1234"     -d '{"keys": ["key1", "key2"]}'
        ```
        """
        return await self._post(
            "/cache/delete",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def flush_all(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """A function to flush all items from the cache.

        (All items will be deleted from
        the cache with this) Raises HTTPException if the cache is not initialized or if
        the cache type does not support flushing. Returns a dictionary with the status
        of the operation.

        Usage:

        ```
        curl -X POST http://0.0.0.0:4000/cache/flushall -H "Authorization: Bearer sk-1234"
        ```
        """
        return await self._post(
            "/cache/flushall",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def ping(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CachePingResponse:
        """Endpoint for checking if cache can be pinged"""
        return await self._get(
            "/cache/ping",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CachePingResponse,
        )


class CacheResourceWithRawResponse:
    def __init__(self, cache: CacheResource) -> None:
        self._cache = cache

        self.delete = to_raw_response_wrapper(
            cache.delete,
        )
        self.flush_all = to_raw_response_wrapper(
            cache.flush_all,
        )
        self.ping = to_raw_response_wrapper(
            cache.ping,
        )

    @cached_property
    def redis(self) -> RedisResourceWithRawResponse:
        return RedisResourceWithRawResponse(self._cache.redis)


class AsyncCacheResourceWithRawResponse:
    def __init__(self, cache: AsyncCacheResource) -> None:
        self._cache = cache

        self.delete = async_to_raw_response_wrapper(
            cache.delete,
        )
        self.flush_all = async_to_raw_response_wrapper(
            cache.flush_all,
        )
        self.ping = async_to_raw_response_wrapper(
            cache.ping,
        )

    @cached_property
    def redis(self) -> AsyncRedisResourceWithRawResponse:
        return AsyncRedisResourceWithRawResponse(self._cache.redis)


class CacheResourceWithStreamingResponse:
    def __init__(self, cache: CacheResource) -> None:
        self._cache = cache

        self.delete = to_streamed_response_wrapper(
            cache.delete,
        )
        self.flush_all = to_streamed_response_wrapper(
            cache.flush_all,
        )
        self.ping = to_streamed_response_wrapper(
            cache.ping,
        )

    @cached_property
    def redis(self) -> RedisResourceWithStreamingResponse:
        return RedisResourceWithStreamingResponse(self._cache.redis)


class AsyncCacheResourceWithStreamingResponse:
    def __init__(self, cache: AsyncCacheResource) -> None:
        self._cache = cache

        self.delete = async_to_streamed_response_wrapper(
            cache.delete,
        )
        self.flush_all = async_to_streamed_response_wrapper(
            cache.flush_all,
        )
        self.ping = async_to_streamed_response_wrapper(
            cache.ping,
        )

    @cached_property
    def redis(self) -> AsyncRedisResourceWithStreamingResponse:
        return AsyncRedisResourceWithStreamingResponse(self._cache.redis)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, Optional, cast

import httpx

from ...types import file_list_params, file_create_params
from .content import (
    ContentResource,
    AsyncContentResource,
    ContentResourceWithRawResponse,
    AsyncContentResourceWithRawResponse,
    ContentResourceWithStreamingResponse,
    AsyncContentResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven, FileTypes
from ..._utils import (
    extract_files,
    maybe_transform,
    deepcopy_minimal,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["FilesResource", "AsyncFilesResource"]


class FilesResource(SyncAPIResource):
    @cached_property
    def content(self) -> ContentResource:
        return ContentResource(self._client)

    @cached_property
    def with_raw_response(self) -> FilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return FilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return FilesResourceWithStreamingResponse(self)

    def create(
        self,
        provider: str,
        *,
        file: FileTypes,
        purpose: str,
        custom_llm_provider: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Upload a file that can be used across - Assistants API, Batch API This is the
        equivalent of POST https://api.openai.com/v1/files

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/create

        Example Curl

        ```
        curl http://localhost:4000/v1/files         -H "Authorization: Bearer sk-1234"         -F purpose="batch"         -F file="@mydata.jsonl"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        body = deepcopy_minimal(
            {
                "file": file,
                "purpose": purpose,
                "custom_llm_provider": custom_llm_provider,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            f"/{provider}/v1/files",
            body=maybe_transform(body, file_create_params.FileCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def retrieve(
        self,
        file_id: str,
        *,
        provider: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Returns information about a specific file.

        that can be used across - Assistants
        API, Batch API This is the equivalent of GET
        https://api.openai.com/v1/files/{file_id}

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/retrieve

        Example Curl

        ```
        curl http://localhost:4000/v1/files/file-abc123         -H "Authorization: Bearer sk-1234"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return self._get(
            f"/{provider}/v1/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def list(
        self,
        provider: str,
        *,
        purpose: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Returns information about a specific file.

        that can be used across - Assistants
        API, Batch API This is the equivalent of GET https://api.openai.com/v1/files/

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/list

        Example Curl

        ```
        curl http://localhost:4000/v1/files        -H "Authorization: Bearer sk-1234"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        return self._get(
            f"/{provider}/v1/files",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"purpose": purpose}, file_list_params.FileListParams),
            ),
            cast_to=object,
        )

    def delete(
        self,
        file_id: str,
        *,
        provider: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Deletes a specified file.

        that can be used across - Assistants API, Batch API
        This is the equivalent of DELETE https://api.openai.com/v1/files/{file_id}

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/delete

        Example Curl

        ```
        curl http://localhost:4000/v1/files/file-abc123     -X DELETE     -H "Authorization: Bearer $OPENAI_API_KEY"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return self._delete(
            f"/{provider}/v1/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncFilesResource(AsyncAPIResource):
    @cached_property
    def content(self) -> AsyncContentResource:
        return AsyncContentResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncFilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/hanzoai/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncFilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/hanzoai/python-sdk#with_streaming_response
        """
        return AsyncFilesResourceWithStreamingResponse(self)

    async def create(
        self,
        provider: str,
        *,
        file: FileTypes,
        purpose: str,
        custom_llm_provider: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Upload a file that can be used across - Assistants API, Batch API This is the
        equivalent of POST https://api.openai.com/v1/files

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/create

        Example Curl

        ```
        curl http://localhost:4000/v1/files         -H "Authorization: Bearer sk-1234"         -F purpose="batch"         -F file="@mydata.jsonl"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        body = deepcopy_minimal(
            {
                "file": file,
                "purpose": purpose,
                "custom_llm_provider": custom_llm_provider,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            f"/{provider}/v1/files",
            body=await async_maybe_transform(body, file_create_params.FileCreateParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def retrieve(
        self,
        file_id: str,
        *,
        provider: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Returns information about a specific file.

        that can be used across - Assistants
        API, Batch API This is the equivalent of GET
        https://api.openai.com/v1/files/{file_id}

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/retrieve

        Example Curl

        ```
        curl http://localhost:4000/v1/files/file-abc123         -H "Authorization: Bearer sk-1234"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return await self._get(
            f"/{provider}/v1/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def list(
        self,
        provider: str,
        *,
        purpose: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Returns information about a specific file.

        that can be used across - Assistants
        API, Batch API This is the equivalent of GET https://api.openai.com/v1/files/

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/list

        Example Curl

        ```
        curl http://localhost:4000/v1/files        -H "Authorization: Bearer sk-1234"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        return await self._get(
            f"/{provider}/v1/files",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"purpose": purpose}, file_list_params.FileListParams),
            ),
            cast_to=object,
        )

    async def delete(
        self,
        file_id: str,
        *,
        provider: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Deletes a specified file.

        that can be used across - Assistants API, Batch API
        This is the equivalent of DELETE https://api.openai.com/v1/files/{file_id}

        Supports Identical Params as:
        https://platform.openai.com/docs/api-reference/files/delete

        Example Curl

        ```
        curl http://localhost:4000/v1/files/file-abc123     -X DELETE     -H "Authorization: Bearer $OPENAI_API_KEY"

        ```

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not provider:
            raise ValueError(f"Expected a non-empty value for `provider` but received {provider!r}")
        if not file_id:
            raise ValueError(f"Expected a non-empty value for `file_id` but received {file_id!r}")
        return await self._delete(
            f"/{provider}/v1/files/{file_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class FilesResourceWithRawResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = to_raw_response_wrapper(
            files.retrieve,
        )
        self.list = to_raw_response_wrapper(
            files.list,
        )
        self.delete = to_raw_response_wrapper(
            files.delete,
        )

    @cached_property
    def content(self) -> ContentResourceWithRawResponse:
        return ContentResourceWithRawResponse(self._files.content)


class AsyncFilesResourceWithRawResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_raw_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            files.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            files.list,
        )
        self.delete = async_to_raw_response_wrapper(
            files.delete,
        )

    @cached_property
    def content(self) -> AsyncContentResourceWithRawResponse:
        return AsyncContentResourceWithRawResponse(self._files.content)


class FilesResourceWithStreamingResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.create = to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            files.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            files.list,
        )
        self.delete = to_streamed_response_wrapper(
            files.delete,
        )

    @cached_property
    def content(self) -> ContentResourceWithStreamingResponse:
        return ContentResourceWithStreamingResponse(self._files.content)


class AsyncFilesResourceWithStreamingResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.create = async_to_streamed_response_wrapper(
            files.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            files.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            files.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            files.delete,
        )

    @cached_property
    def content(self) -> AsyncContentResourceWithStreamingResponse:
        return AsyncContentResourceWithStreamingResponse(self._files.content)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["UserCreateResponse"]


class UserCreateResponse(BaseModel):
    expires: Optional[datetime] = None

    key: str

    token: Optional[str] = None

    aliases: Optional[object] = None

    allowed_cache_controls: Optional[List[object]] = None

    blocked: Optional[bool] = None

    budget_duration: Optional[str] = None

    budget_id: Optional[str] = None

    config: Optional[object] = None

    created_by: Optional[str] = None

    duration: Optional[str] = None

    enforced_params: Optional[List[str]] = None

    guardrails: Optional[List[str]] = None

    key_alias: Optional[str] = None

    key_name: Optional[str] = None

    litellm_budget_table: Optional[object] = None

    max_budget: Optional[float] = None

    max_parallel_requests: Optional[int] = None

    metadata: Optional[object] = None

    api_model_max_budget: Optional[object] = FieldInfo(alias="model_max_budget", default=None)

    api_model_rpm_limit: Optional[object] = FieldInfo(alias="model_rpm_limit", default=None)

    api_model_tpm_limit: Optional[object] = FieldInfo(alias="model_tpm_limit", default=None)

    models: Optional[List[object]] = None

    permissions: Optional[object] = None

    rpm_limit: Optional[int] = None

    spend: Optional[float] = None

    tags: Optional[List[str]] = None

    team_id: Optional[str] = None

    teams: Optional[List[object]] = None

    token_id: Optional[str] = None

    tpm_limit: Optional[int] = None

    updated_by: Optional[str] = None

    user_alias: Optional[str] = None

    user_email: Optional[str] = None

    user_id: Optional[str] = None

    user_role: Optional[Literal["proxy_admin", "proxy_admin_viewer", "internal_user", "internal_user_viewer"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, TypedDict

__all__ = ["HealthCheckServicesParams"]


class HealthCheckServicesParams(TypedDict, total=False):
    service: Required[
        Union[
            Literal[
                "slack_budget_alerts", "langfuse", "slack", "openmeter", "webhook", "email", "braintrust", "datadog"
            ],
            str,
        ]
    ]
    """Specify the service being hit."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["CustomerUpdateParams"]


class CustomerUpdateParams(TypedDict, total=False):
    user_id: Required[str]

    alias: Optional[str]

    allowed_model_region: Optional[Literal["eu", "us"]]

    blocked: bool

    budget_id: Optional[str]

    default_model: Optional[str]

    max_budget: Optional[float]
